==> jc-1.4.0.tar.gz: javax/swing/Spring__24MinusSpring.h <==
// final class javax.swing.Spring$MinusSpring

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 52c68a5c6f02978c javax_swing_Spring
// @dep_class e8dd3e305076c750 javax_swing_Spring__24MinusSpring

// header file dependencies
// @dep_header javax_swing_Spring

#include "javax/swing/Spring.h"

#ifndef _JC_javax_swing_Spring__24MinusSpring_H_
#define _JC_javax_swing_Spring__24MinusSpring_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Spring$object;

// Typedefs
typedef struct _jc_javax_swing_Spring__24MinusSpring$sub_refs	_jc_javax_swing_Spring__24MinusSpring$sub_refs;
typedef struct _jc_javax_swing_Spring__24MinusSpring$sub_nonrefs	_jc_javax_swing_Spring__24MinusSpring$sub_nonrefs;
typedef struct _jc_javax_swing_Spring__24MinusSpring$refs	_jc_javax_swing_Spring__24MinusSpring$refs;
typedef struct _jc_javax_swing_Spring__24MinusSpring$nonrefs	_jc_javax_swing_Spring__24MinusSpring$nonrefs;
typedef struct _jc_javax_swing_Spring__24MinusSpring$object	_jc_javax_swing_Spring__24MinusSpring$object;

typedef const struct _jc_javax_swing_Spring__24MinusSpring$vmethods	_jc_javax_swing_Spring__24MinusSpring$vmethods;
typedef const struct _jc_javax_swing_Spring__24MinusSpring$vtable	_jc_javax_swing_Spring__24MinusSpring$vtable;
typedef const struct _jc_javax_swing_Spring__24MinusSpring$vtype	_jc_javax_swing_Spring__24MinusSpring$vtype;

// Constructors
extern void _jc_javax_swing_Spring__24MinusSpring$method$_init$52af8cb1beb4092f(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *, struct _jc_javax_swing_Spring$object *);

// Virtual methods
extern jint _jc_javax_swing_Spring__24MinusSpring$method$getMaximumValue$dd51e3d6fecde040(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *);
extern jint _jc_javax_swing_Spring__24MinusSpring$method$getMinimumValue$a7d66b63a1df3c72(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *);
extern jint _jc_javax_swing_Spring__24MinusSpring$method$getPreferredValue$c216b16eb60a1689(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *);
extern jint _jc_javax_swing_Spring__24MinusSpring$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *);
extern void _jc_javax_swing_Spring__24MinusSpring$method$setValue$e6840ec6b97bf5b1(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Spring__24MinusSpring$method_info$getMaximumValue$dd51e3d6fecde040;
extern _jc_method _jc_javax_swing_Spring__24MinusSpring$method_info$getMinimumValue$a7d66b63a1df3c72;
extern _jc_method _jc_javax_swing_Spring__24MinusSpring$method_info$getPreferredValue$c216b16eb60a1689;
extern _jc_method _jc_javax_swing_Spring__24MinusSpring$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_javax_swing_Spring__24MinusSpring$method_info$setValue$e6840ec6b97bf5b1;

// Virtual methods structure
struct _jc_javax_swing_Spring__24MinusSpring$vmethods {
	jint	(*getMaximumValue$dd51e3d6fecde040)(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *);
	jint	(*getMinimumValue$a7d66b63a1df3c72)(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *);
	jint	(*getPreferredValue$c216b16eb60a1689)(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *);
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *);
	void	(*setValue$e6840ec6b97bf5b1)(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *, jint);
};

// Vtable
struct _jc_javax_swing_Spring__24MinusSpring$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Spring$vmethods	javax_swing_Spring;
	_jc_javax_swing_Spring__24MinusSpring$vmethods	javax_swing_Spring__24MinusSpring;
};

// Vtype
struct _jc_javax_swing_Spring__24MinusSpring$vtype {
	_jc_type			type;
	_jc_javax_swing_Spring__24MinusSpring$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Spring__24MinusSpring$sub_refs {
	struct _jc_javax_swing_Spring$object	*s;
};

// Reference instance fields (object)
struct _jc_javax_swing_Spring__24MinusSpring$refs {
    _jc_javax_swing_Spring__24MinusSpring$sub_refs	javax_swing_Spring__24MinusSpring;
    _jc_javax_swing_Spring$sub_refs	javax_swing_Spring;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Spring__24MinusSpring$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Spring__24MinusSpring$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Spring$sub_nonrefs	javax_swing_Spring;
    _jc_javax_swing_Spring__24MinusSpring$sub_nonrefs	javax_swing_Spring__24MinusSpring;
};

// Object instance structure
struct _jc_javax_swing_Spring__24MinusSpring$object {
	_jc_javax_swing_Spring__24MinusSpring$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Spring__24MinusSpring$vtype	*vtype;
	_jc_javax_swing_Spring__24MinusSpring$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Spring__24MinusSpring$vtype _jc_javax_swing_Spring__24MinusSpring$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Spring__24MinusSpring, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Spring__24MinusSpring$class_object;

#endif	/* _JC_javax_swing_Spring__24MinusSpring_H_ */

==> jc-1.4.6.tar.gz: javax/swing/Spring__24MinusSpring.h <==
// final class javax.swing.Spring$MinusSpring

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 52c68a5c6f02978c javax_swing_Spring
// @dep_class e8dd3e305076c750 javax_swing_Spring__24MinusSpring

// header file dependencies
// @dep_header javax_swing_Spring

#include "javax/swing/Spring.h"

#ifndef _JC_javax_swing_Spring__24MinusSpring_H_
#define _JC_javax_swing_Spring__24MinusSpring_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Spring$object;

// Typedefs
typedef struct _jc_javax_swing_Spring__24MinusSpring$sub_refs	_jc_javax_swing_Spring__24MinusSpring$sub_refs;
typedef struct _jc_javax_swing_Spring__24MinusSpring$sub_nonrefs	_jc_javax_swing_Spring__24MinusSpring$sub_nonrefs;
typedef struct _jc_javax_swing_Spring__24MinusSpring$refs	_jc_javax_swing_Spring__24MinusSpring$refs;
typedef struct _jc_javax_swing_Spring__24MinusSpring$nonrefs	_jc_javax_swing_Spring__24MinusSpring$nonrefs;
typedef struct _jc_javax_swing_Spring__24MinusSpring$object	_jc_javax_swing_Spring__24MinusSpring$object;

typedef const struct _jc_javax_swing_Spring__24MinusSpring$vmethods	_jc_javax_swing_Spring__24MinusSpring$vmethods;
typedef const struct _jc_javax_swing_Spring__24MinusSpring$vtable	_jc_javax_swing_Spring__24MinusSpring$vtable;
typedef const struct _jc_javax_swing_Spring__24MinusSpring$vtype	_jc_javax_swing_Spring__24MinusSpring$vtype;

// Constructors
extern void _jc_javax_swing_Spring__24MinusSpring$method$_init$52af8cb1beb4092f(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *, struct _jc_javax_swing_Spring$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_Spring__24MinusSpring$method$getMaximumValue$dd51e3d6fecde040(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_Spring__24MinusSpring$method$getMinimumValue$a7d66b63a1df3c72(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_Spring__24MinusSpring$method$getPreferredValue$c216b16eb60a1689(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_Spring__24MinusSpring$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_Spring__24MinusSpring$method$setValue$e6840ec6b97bf5b1(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Spring__24MinusSpring$method_info$getMaximumValue$dd51e3d6fecde040;
extern _jc_method _jc_javax_swing_Spring__24MinusSpring$method_info$getMinimumValue$a7d66b63a1df3c72;
extern _jc_method _jc_javax_swing_Spring__24MinusSpring$method_info$getPreferredValue$c216b16eb60a1689;
extern _jc_method _jc_javax_swing_Spring__24MinusSpring$method_info$getValue$245714dca3f59de3;
extern _jc_method _jc_javax_swing_Spring__24MinusSpring$method_info$setValue$e6840ec6b97bf5b1;

// Virtual methods structure
struct _jc_javax_swing_Spring__24MinusSpring$vmethods {
	jint	(*getMaximumValue$dd51e3d6fecde040)(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *) _JC_JCNI_ATTR;
	jint	(*getMinimumValue$a7d66b63a1df3c72)(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *) _JC_JCNI_ATTR;
	jint	(*getPreferredValue$c216b16eb60a1689)(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *) _JC_JCNI_ATTR;
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *) _JC_JCNI_ATTR;
	void	(*setValue$e6840ec6b97bf5b1)(_jc_env *, struct _jc_javax_swing_Spring__24MinusSpring$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_Spring__24MinusSpring$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Spring$vmethods	javax_swing_Spring;
	_jc_javax_swing_Spring__24MinusSpring$vmethods	javax_swing_Spring__24MinusSpring;
};

// Vtype
struct _jc_javax_swing_Spring__24MinusSpring$vtype {
	_jc_type			type;
	_jc_javax_swing_Spring__24MinusSpring$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Spring__24MinusSpring$sub_refs {
	struct _jc_javax_swing_Spring$object	*s;
};

// Reference instance fields (object)
struct _jc_javax_swing_Spring__24MinusSpring$refs {
    _jc_javax_swing_Spring__24MinusSpring$sub_refs	javax_swing_Spring__24MinusSpring;
    _jc_javax_swing_Spring$sub_refs	javax_swing_Spring;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Spring__24MinusSpring$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Spring__24MinusSpring$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Spring$sub_nonrefs	javax_swing_Spring;
    _jc_javax_swing_Spring__24MinusSpring$sub_nonrefs	javax_swing_Spring__24MinusSpring;
};

// Object instance structure
struct _jc_javax_swing_Spring__24MinusSpring$object {
	_jc_javax_swing_Spring__24MinusSpring$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Spring__24MinusSpring$vtype	*vtype;
	_jc_javax_swing_Spring__24MinusSpring$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Spring__24MinusSpring$vtype _jc_javax_swing_Spring__24MinusSpring$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Spring__24MinusSpring, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Spring__24MinusSpring$class_object;

#endif	/* _JC_javax_swing_Spring__24MinusSpring_H_ */
